@@ -13,7 +13,7 @@ from markdown import markdown
 
 from .utils import alert, details
 from .shared_vars import _md_extensions
-from .objs_formatter import _fix_code
+from .formatter import _fix_code
     
 
 # Do not use this in main work, just inside a function
@@ -27,6 +27,9 @@ class _Source_Widget(ipw.HTML):
     def _repr_html_(self):
         "Make it available in `write` command as well."
         return self.value
+    
+    def __format__(self, spec):
+        return f'{self.value:{spec}}'
         
     def show_lines(self, lines):
         "Return source object with selected lines from list/tuple/range of lines."
@@ -102,7 +105,13 @@ def _file2code(filename,language='python',name=None):
     
     code = f'''<style> div.codehilite.{_class}::before {{
                 content: '🔴 🟡 🟢  {_title}' !important;
-            }}</style>''' + code
+            }}
+            div.codehilite .highlight {{
+                width: 100% !important;
+                height: 100% !important;
+            }}
+            div.codehilite .highlight code:first-child {{ padding-left: 0 !important;}}
+            </style>''' + code
     out = _Source_Widget(value = _fix_code(code))
     out.raw = text 
     return out
@@ -168,7 +177,7 @@ class Source:
 
         file, l1 = frame()
         _alert = alert('You can get code once you exit context manager for `write` command <center>OR</center>use it will auto update inside `iwrite` command')
-        return_obj = _Source_Widget(value=_alert)
+        return_obj = _Source_Widget(value=f'{_alert}')
         return_obj.raw = ''
 
         cls.current = return_obj # add to user namespace, this does not create extra object, just points to same
@@ -183,7 +192,7 @@ class Source:
             out_code = _str2code(code).value #needs further processing
 
             if collapsed:
-                return_obj._code =  details(out_code,summary='Show Code')
+                return_obj._code =  details(out_code,summary='Show Code').value #details is _HTML
             else:
                 return_obj._code = out_code 
                 
