@@ -1,8 +1,8 @@
-__all__ = ['print_context',  'details', 'plt2html', 'set_dir', 'textbox',
+__all__ = ['print_context',  'details', 'plt2html', 'set_dir', 'textbox', 'vspace',
             'image','svg','format_html','format_css','alert','colored','keep_format',
-            'raw','enable_zoom','html_node','sig','doc']
-__all__.extend(['rows','block'])
-__all__.extend([f'block_{c}' for c in ['r','g','b','y','c','m','k','o','w','p']])
+            'raw','enable_zoom','html','sig','doc']
+__all__.extend(['rows','cols','block'])
+__all__.extend([f'block_{c}' for c in 'rgbycmkowp'])
 
 
 import os
@@ -10,12 +10,12 @@ import inspect
 from io import BytesIO # For PIL image
 from contextlib import contextmanager
 
-from IPython.display import HTML,  SVG
+from IPython.display import SVG
 from IPython.utils.capture import capture_output
 from IPython.core.display import Image
 import ipywidgets as ipw
 
-from .objs_formatter import fix_ipy_image
+from .formatter import fix_ipy_image, _HTML
 from .writers import write, _fmt_write, _fix_repr
  
         
@@ -30,6 +30,7 @@ def print_context():
     
 @contextmanager
 def set_dir(path):
+    "Context manager to set working directory to given path and return to previous working directory when done."
     current = os.getcwd()
     try:
         os.chdir(path)
@@ -38,20 +39,20 @@ def set_dir(path):
         os.chdir(current)
 
 def format_html(*columns,width_percents=None,className=None):
-    'Same as `write` except it does not display but give a dict object that can be passed to `write` and `iwrite`.'
-    return keep_format(_fmt_write(*columns,width_percents=width_percents,className=className))
+    'Same as `write` except it does not write xplicitly, provide in write function'
+    return _HTML(_fmt_write(*columns,width_percents=width_percents,className=className))
 
 def format_css(selector, **css_props):
     "Provide CSS values with - replaced by _ e.g. font-size to font_size. selector is a string of valid tag/class/id etc."
     _css_props = {k.replace('_','-'):f"{v}" for k,v in css_props.items()} #Convert to CSS string if int or float
-    _css_props = {k:v.replace('!important','').replace(';','') + '!important;' for k,v in _css_props.items()}
+    _css_props = {k: f"{v.replace('!important','').replace(';','')} !important;" for k,v in _css_props.items()}
     props_str = '\n'.join([f"    {k}: {v}" for k,v in _css_props.items()])
     out_str = f"<style>\n{selector} {{\n{props_str}\n}}\n</style>"
-    return keep_format(out_str)
+    return _HTML(out_str)
         
 def details(str_html,summary='Click to show content'):
     "Show/Hide Content in collapsed html."
-    return f"""<details style='max-height:100%;overflow:auto;'><summary>{summary}</summary>{str_html}</details>"""
+    return _HTML(f"""<details style='max-height:100%;overflow:auto;'><summary>{summary}</summary>{str_html}</details>""")
 
 def __check_pil_image(data):
     "Check if data is a PIL Image or numpy array"
@@ -64,47 +65,52 @@ def __check_pil_image(data):
 def image(data=None,width='80%',caption=None, zoomable=True,**kwargs):
     """Displays PNG/JPEG files or image data etc, `kwrags` are passed to IPython.display.Image. 
     You can provide following to `data` parameter:
-        - An opened PIL image. Useful for image operations and then direct writing to slides. 
-        - A file path to image file.
-        - A url to image file.
-        - A str/bytes object containing image data.  
+        
+    - An opened PIL image. Useful for image operations and then direct writing to slides. 
+    - A file path to image file.
+    - A url to image file.
+    - A str/bytes object containing image data.  
     """
     if isinstance(width,int):
         width = f'{width}px'
     _data = __check_pil_image(data) #Check if data is a PIL Image or return data
-    img = fix_ipy_image(Image(data = _data,**kwargs),width=width)
-    if caption:
-        img = img + textbox(caption)  # Add caption
+    img = fix_ipy_image(Image(data = _data,**kwargs),width=width) # gievs _HTML object
+    cap = f'<figcaption>{caption}</figcaption>' if caption else ''
+    img = html('figure', img.value + cap)  # Add caption,  _HTML + _HTML
     if zoomable:
-        return f'<div class="zoom-container">{img}</div>'
-    return img
+        return _HTML(f'<div class="zoom-container">{img}</div>')
+    return _HTML(img)
 
 def svg(data=None,caption=None,zoomable=True,**kwargs):
     "Display svg file or svg string/bytes with additional customizations. `kwrags` are passed to IPython.display.SVG. You can provide url/string/bytes/filepath for svg."
     svg = SVG(data=data, **kwargs)._repr_svg_()
-    if caption:
-        svg = svg + textbox(caption)  # Add caption 
+    cap = f'<figcaption>{caption}</figcaption>' if caption else ''
+    svg = html('figure', svg + cap)
     if zoomable:
-        return f'<div class="zoom-container">{svg}</div>'
-    return svg
+        return _HTML(f'<div class="zoom-container">{svg}</div>')
+    return _HTML(svg)
 
 def enable_zoom(obj):
     "Add zoom-container class to given object, whether a widget or html/IPYthon object"
     try:
         return ipw.Box([obj]).add_class('zoom-container')
     except:
-        return {'__keep_format__': f'<div class="zoom-container">{_fix_repr(obj)}</div>'}
+        return _HTML(f'<div class="zoom-container">{_fix_repr(obj)}</div>')
     
-def html_node(tag,children = [],className = None,**node_attrs):
+def html(tag,children = [],className = None,**node_attrs):
     """Returns html node with given children and node attributes like style, id etc.
     `tag` can be any valid html tag name.
     `children` expects:
-        - str: A string to be added as node's text content.
-        - html_node: A html_node to be added as child node.
-        - list/tuple of [str, html_node]: A list of str and html_node to be added as child nodes.
+    
+    - str: A string to be added as node's text content.
+    - html: A html to be added as child node.
+    - list/tuple of [str, html]: A list of str and html to be added as child nodes.
+    
     Example:
-        html_node('img',src='ir_uv.jpg') #Returns IPython.display.HTML("<img src='ir_uv.jpg'></img>") and displas image if last line in notebook's cell.
-        """
+    ```python
+    html('img',src='ir_uv.jpg') #Returns IPython.display.HTML("<img src='ir_uv.jpg'></img>") and displas image if last line in notebook's cell.
+    ```
+    """
     if isinstance(children,str):
         content = children
     elif isinstance(children,(list,tuple)):
@@ -113,12 +119,15 @@ def html_node(tag,children = [],className = None,**node_attrs):
         try:
             content = children._repr_html_() #Try to get html representation of children if HTML object
         except:
-            raise ValueError(f'Children should be a list/tuple of html_node or str, not {type(children)}')
+            raise ValueError(f'Children should be a list/tuple of html or str, not {type(children)}')
     attrs = ' '.join(f'{k}="{v}"' for k,v in node_attrs.items()) # Join with space is must
     if className:
-        attrs = f'class="{className}"' + ' ' + attrs # space is must after className
-    return HTML(f'<{tag} {attrs}>{content}</{tag}>')
+        attrs = f'class="{className}" {attrs}' # space is must after className
+    return _HTML(f'<{tag} {attrs}>{content}</{tag}>')
 
+def vspace(em = 1):
+    "Returns html node with given height in em"
+    return html('div',style=f'height:{em}em;')
  
 def textbox(text, **css_props):
     """Formats text in a box for writing e.g. inline refrences. `css_props` are applied to box and `-` should be `_` like `font-size` -> `font_size`. 
@@ -126,36 +135,40 @@ def textbox(text, **css_props):
     css_props = {'display':'inline-block','white-space': 'pre', **css_props} # very important to apply text styles in order
     # white-space:pre preserves whitspacing, text will be viewed as written. 
     _style = ' '.join([f"{key.replace('_','-')}:{value};" for key,value in css_props.items()])
-    return f"<span class='TextBox' style = {_style!r}> {text} </span>"  # markdown="span" will avoid inner parsing
+    return _HTML(f"<span class='TextBox' style = {_style!r}>{text}</span>")  # markdown="span" will avoid inner parsing
 
 def alert(text):
     "Alerts text!"
-    return f"<span style='color:#DC143C;'>{text}</span>"
+    return _HTML(f"<span style='color:#DC143C;'>{text}</span>")
     
 def colored(text,fg='blue',bg=None):
     "Colored text, `fg` and `bg` should be valid CSS colors"
-    return f"<span style='background:{bg};color:{fg};'>{text}</span>"
+    return _HTML(f"<span style='background:{bg};color:{fg};'>{text}</span>")
 
 def keep_format(plaintext_or_html):
     "Bypasses from being parsed by markdown parser. Useful for some graphs, e.g. keep_raw(obj.to_html()) preserves its actual form."
     if not isinstance(plaintext_or_html,str):
         return plaintext_or_html # if not string, return as is
-    return {'__keep_format__':plaintext_or_html} 
+    return _HTML(plaintext_or_html) 
 
 def raw(text):
     "Keep shape of text as it is, preserving whitespaces as well."
-    return {'__keep_format__':f"<div class='PyRepr'>{text}<div>"}
+    return _HTML(f"<div class='PyRepr'>{text}<div>")
 
-def rows(*objs):
+def rows(*objs, className=None):
     "Returns tuple of objects. Use in `write`, `iwrite` for better readiability of writing rows in a column."
-    return objs # Its already a tuple
+    return format_html(objs,className = className) # Its already a tuple, so will show in a column with many rows
+
+def cols(*objs,width_percents=None, className=None):
+    "Returns HTML containing multiple columns of given width_percents."
+    return format_html(*objs,width_percents=width_percents,className = className)
 
 def block(title,*objs,bg = 'olive'):
     "Format a block like in LATEX beamer. *objs expect to be writable with `write` command."
     _title = f"""<center style='background:var(--secondary-bg);margin:0px -4px;'>
                 <b>{title}</b></center>"""
     _out = _fmt_write(objs) # single column
-    return keep_format(f"""<div style='padding:4px' class='block'>
+    return _HTML(f"""<div style='padding:4px' class='block'>
         <div style='border-top:4px solid {bg};box-shadow: 0px 0px 4px {bg};border-radius:4px;padding:0 4px;'>
         {_title}
         {_out}
@@ -197,8 +210,8 @@ def sig(callable,prepend_str = None):
     try:
         _sig = f'<b>{callable.__name__}</b><span style="font-size:85%;color:var(--secondary-fg);">{str(inspect.signature(callable))}</span>'
         if prepend_str: 
-            _sig = alert(prepend_str + '.') + _sig
-        return {'__keep_format__':_sig}
+            _sig = f'{alert(prepend_str)}.{_sig}' # must be inside format string
+        return _HTML(_sig)
     except:
         raise TypeError(f'Object {callable} is not a callable')
 
@@ -206,9 +219,8 @@ def doc(callable,prepend_str = None):
     "Returns documentation of a callable. You can prepend a class/module name."
     try:
         _doc = _fix_repr(inspect.getdoc(callable))
-        _sig = sig(callable,prepend_str)['__keep_format__']
-        return {'__keep_format__':f"<div class='PyRepr'>{_sig}<br>{_doc}</div>"}
+        _sig = sig(callable,prepend_str)
+        return _HTML(f"<div class='Docs'>{_sig}<br>{_doc}</div>")
     except:
         raise TypeError(f'Object {callable} is not a callable')
-
-    
+    
\ No newline at end of file
